@@ -13,9 +13,10 @@ import copy
 import collections
 import datetime
 
+import nbformat
+
 from traitlets.config.configurable import LoggingConfigurable
 from traitlets.config import Config
-import nbformat
 from traitlets import HasTraits, Unicode, List, TraitError
 from traitlets.utils.importstring import import_item
 from ipython_genutils import text, py3compat
@@ -46,8 +47,8 @@ class FilenameExtension(Unicode):
 
 class Exporter(LoggingConfigurable):
     """
-    Class containing methods that sequentially run a list of preprocessors on a 
-    NotebookNode object and then return the modified NotebookNode object and 
+    Class containing methods that sequentially run a list of preprocessors on a
+    NotebookNode object and then return the modified NotebookNode object and
     accompanying resources dict.
     """
 
@@ -60,6 +61,10 @@ class Exporter(LoggingConfigurable):
     # the class, not just on instances.
     output_mimetype = ''
 
+    # Should this converter be accessible from the notebook front-end?
+    # If so, should be a friendly name to display (and possibly translated).
+    export_from_notebook = None
+
     #Configurability, allows the user to easily add filters and preprocessors.
     preprocessors = List(
         help="""List of preprocessors, by name or namespace, to enable."""
@@ -68,6 +73,8 @@ class Exporter(LoggingConfigurable):
     _preprocessors = List()
 
     default_preprocessors = List([
+                                  'nbconvert.preprocessors.TagRemovePreprocessor',
+                                  'nbconvert.preprocessors.RegexRemovePreprocessor',
                                   'nbconvert.preprocessors.ClearOutputPreprocessor',
                                   'nbconvert.preprocessors.ExecutePreprocessor',
                                   'nbconvert.preprocessors.coalesce_streams',
@@ -76,8 +83,9 @@ class Exporter(LoggingConfigurable):
                                   'nbconvert.preprocessors.LatexPreprocessor',
                                   'nbconvert.preprocessors.HighlightMagicsPreprocessor',
                                   'nbconvert.preprocessors.ExtractOutputPreprocessor',
+                                  'nbconvert.preprocessors.ClearMetadataPreprocessor',
                               ],
-        help="""List of preprocessors available by default, by name, namespace, 
+        help="""List of preprocessors available by default, by name, namespace,
         instance, or type."""
     ).tag(config=True)
 
@@ -96,7 +104,7 @@ class Exporter(LoggingConfigurable):
         with_default_config = self.default_config
         if config:
             with_default_config.merge(config)
-        
+
         super(Exporter, self).__init__(config=with_default_config, **kw)
 
         self._init_preprocessors()
@@ -123,7 +131,7 @@ class Exporter(LoggingConfigurable):
         """
         nb_copy = copy.deepcopy(nb)
         resources = self._init_resources(resources)
-        
+
         if 'language' in nb['metadata']:
             resources['language'] = nb['metadata']['language'].lower()
 
@@ -148,6 +156,11 @@ class Exporter(LoggingConfigurable):
           Ignored
 
         """
+        # Convert full filename string to unicode
+        # In python 2.7.x if filename comes as unicode string,
+        # just skip converting it.
+        if isinstance(filename, str):
+           filename = py3compat.str_to_unicode(filename)
 
         # Pull the metadata from the filesystem.
         if resources is None:
@@ -221,7 +234,7 @@ class Exporter(LoggingConfigurable):
             return preprocessor
 
         elif isclass and issubclass(preprocessor, HasTraits):
-            # Preprocessor is configurable.  Make sure to pass in new default for 
+            # Preprocessor is configurable.  Make sure to pass in new default for
             # the enabled flag if one was specified.
             self.register_preprocessor(preprocessor(parent=self), enabled)
 
@@ -230,8 +243,8 @@ class Exporter(LoggingConfigurable):
             self.register_preprocessor(preprocessor(), enabled)
 
         else:
-            # Preprocessor is an instance of something without a __call__ 
-            # attribute.  
+            # Preprocessor is an instance of something without a __call__
+            # attribute.
             raise TypeError('preprocessor must be callable or an importable constructor, got %r' % preprocessor)
 
 
@@ -301,4 +314,11 @@ class Exporter(LoggingConfigurable):
         #to each preprocessor
         for preprocessor in self._preprocessors:
             nbc, resc = preprocessor(nbc, resc)
+            try: 
+                nbformat.validate(nbc, relax_add_props=True)
+            except nbformat.ValidationError:
+                self.log.error('Notebook is invalid after preprocessor {}',
+                               preprocessor)
+                raise
+
         return nbc, resc
