@@ -17,7 +17,10 @@ try:
     from urllib.parse import quote  # Py 3
 except ImportError:
     from urllib2 import quote  # Py 2
-from xml.etree import ElementTree
+
+# defusedxml does safe(r) parsing of untrusted XML data
+from defusedxml import cElementTree as ElementTree
+from xml.etree.cElementTree import Element
 
 from ipython_genutils import py3compat
 
@@ -86,7 +89,7 @@ def _convert_header_id(header_contents):
     """
     return header_contents.replace(' ', '-')
 
-def add_anchor(html):
+def add_anchor(html, anchor_link_text=u'¶'):
     """Add an id and an anchor-link to an html header
     
     For use on markdown headings
@@ -98,8 +101,8 @@ def add_anchor(html):
         return html
     link = _convert_header_id(html2text(h))
     h.set('id', link)
-    a = ElementTree.Element("a", {"class" : "anchor-link", "href" : "#" + link})
-    a.text = u'¶'
+    a = Element("a", {"class" : "anchor-link", "href" : "#" + link})
+    a.text = anchor_link_text
     h.append(a)
 
     # Known issue of Python3.x, ElementTree.tostring() returns a byte string
