@@ -17,12 +17,13 @@ import glob
 from jupyter_core.application import JupyterApp, base_aliases, base_flags
 from traitlets.config import catch_config_error, Configurable
 from traitlets import (
-    Unicode, List, Instance, DottedObjectName, Type, Bool
+    Unicode, List, Instance, DottedObjectName, Type, Bool,
+    default, observe,
 )
 
-from ipython_genutils.importstring import import_item
+from traitlets.utils.importstring import import_item
 
-from .exporters.export import get_export_names, get_exporter
+from .exporters.base import get_export_names, get_exporter
 from nbconvert import exporters, preprocessors, writers, postprocessors, __version__
 from .utils.base import NbConvertBase
 from .utils.exceptions import ConversionException
@@ -86,13 +87,42 @@ nbconvert_flags.update({
         {
             'NbConvertApp' : {
                 'use_output_suffix' : False,
-                'export_format': 'notebook',
+                'export_format' : 'notebook',
             },
-            'FilesWriter': {'build_directory': ''},
+            'FilesWriter' : {'build_directory': ''},
         },
         """Run nbconvert in place, overwriting the existing notebook (only 
         relevant when converting to notebook format)"""
-        )
+        ),
+    'clear-output' : (
+        {
+            'NbConvertApp' : {
+                'use_output_suffix' : False,
+                'export_format' : 'notebook',
+            },
+            'FilesWriter' : {'build_directory': ''},
+            'ClearOutputPreprocessor' : {'enabled' : True},
+        },
+        """Clear output of current file and save in place, 
+        overwriting the existing notebook. """
+        ),
+    'no-prompt' : (
+        {'TemplateExporter' : {
+            'exclude_input_prompt' : True,
+            'exclude_output_prompt' : True,
+            }
+        },
+        "Exclude input and output prompts from converted document."
+        ),
+    'no-input' : (
+        {'TemplateExporter' : {
+            'exclude_output_prompt' : True,
+            'exclude_input': True,
+            }
+        },
+        """Exclude input cells and output prompts from converted document. 
+        This mode is ideal for generating code-free reports."""
+        ),
 })
 
 
@@ -104,10 +134,12 @@ class NbConvertApp(JupyterApp):
     aliases = nbconvert_aliases
     flags = nbconvert_flags
     
+    @default('log_level')
     def _log_level_default(self):
         return logging.INFO
     
     classes = List()
+    @default('classes')
     def _classes_default(self):
         classes = [NbConvertBase]
         for pkg in (exporters, preprocessors, writers, postprocessors):
@@ -124,16 +156,22 @@ class NbConvertApp(JupyterApp):
 
         WARNING: THE COMMANDLINE INTERFACE MAY CHANGE IN FUTURE RELEASES.""")
 
-    output_base = Unicode('', config=True, help='''overwrite base name use for output files.
+    output_base = Unicode('', help='''overwrite base name use for output files.
             can only be used when converting one notebook at a time.
-            ''')
+            ''').tag(config=True)
 
     use_output_suffix = Bool(
         True, 
-        config=True,
         help="""Whether to apply a suffix prior to the extension (only relevant
             when converting to notebook format). The suffix is determined by
-            the exporter, and is usually '.nbconvert'.""")
+            the exporter, and is usually '.nbconvert'."""
+    ).tag(config=True)
+
+    output_files_dir = Unicode('{notebook_name}_files',
+         help='''Directory to copy extra files (figures) to.
+               '{notebook_name}' in the string will be converted to notebook
+               basename'''
+    ).tag(config=True)
 
     examples = Unicode(u"""
         The simplest way to use nbconvert is
@@ -143,7 +181,7 @@ class NbConvertApp(JupyterApp):
         which will convert mynotebook.ipynb to the default format (probably HTML).
         
         You can specify the export format with `--to`.
-        Options include {0}
+        Options include {formats}.
         
         > jupyter nbconvert --to latex mynotebook.ipynb
 
@@ -176,21 +214,23 @@ class NbConvertApp(JupyterApp):
             c.NbConvertApp.notebooks = ["my_notebook.ipynb"]
         
         > jupyter nbconvert --config mycfg.py
-        """.format(get_export_names()))
+        """.format(formats=get_export_names()))
 
     # Writer specific variables
-    writer = Instance('nbconvert.writers.base.WriterBase',  
+    writer = Instance('nbconvert.writers.base.WriterBase',
                       help="""Instance of the writer class used to write the 
                       results of the conversion.""", allow_none=True)
-    writer_class = DottedObjectName('FilesWriter', config=True, 
+    writer_class = DottedObjectName('FilesWriter',
                                     help="""Writer class used to write the 
-                                    results of the conversion""")
+                                    results of the conversion""").tag(config=True)
     writer_aliases = {'fileswriter': 'nbconvert.writers.files.FilesWriter',
                       'debugwriter': 'nbconvert.writers.debug.DebugWriter',
                       'stdoutwriter': 'nbconvert.writers.stdout.StdoutWriter'}
     writer_factory = Type(allow_none=True)
-
-    def _writer_class_changed(self, name, old, new):
+    
+    @observe('writer_class')
+    def _writer_class_changed(self, change):
+        new = change['new']
         if new.lower() in self.writer_aliases:
             new = self.writer_aliases[new.lower()]
         self.writer_factory = import_item(new)
@@ -200,32 +240,40 @@ class NbConvertApp(JupyterApp):
                       help="""Instance of the PostProcessor class used to write the
                       results of the conversion.""", allow_none=True)
 
-    postprocessor_class = DottedOrNone(config=True, 
+    postprocessor_class = DottedOrNone(
                                     help="""PostProcessor class used to write the
-                                    results of the conversion""")
+                                    results of the conversion"""
+    ).tag(config=True)
     postprocessor_aliases = {'serve': 'nbconvert.postprocessors.serve.ServePostProcessor'}
     postprocessor_factory = Type(None, allow_none=True)
-
-    def _postprocessor_class_changed(self, name, old, new):
+    
+    @observe('postprocessor_class')
+    def _postprocessor_class_changed(self, change):
+        new = change['new']
         if new.lower() in self.postprocessor_aliases:
             new = self.postprocessor_aliases[new.lower()]
         if new:
             self.postprocessor_factory = import_item(new)
 
+    ipywidgets_base_url = Unicode("https://unpkg.com/",
+                                  help="URL base for ipywidgets package").tag(config=True)
+
 
     export_format = Unicode(
         'html',
-        allow_none=False, config=True,
-        help="""The export format to be used, either one of the built-in formats,
+        allow_none=False,
+        help="""The export format to be used, either one of the built-in formats
+        {formats}
         or a dotted object name that represents the import path for an
-        `Exporter` class"""
-    )
+        `Exporter` class""".format(formats=get_export_names())
+    ).tag(config=True)
 
-    notebooks = List([], config=True, help="""List of notebooks to convert.
+    notebooks = List([], help="""List of notebooks to convert.
                      Wildcards are supported.
                      Filenames passed positionally will be added to the list.
-                     """)
-    from_stdin   = Bool(False, config=True, help="read a single notebook from stdin.")
+                     """
+    ).tag(config=True)
+    from_stdin = Bool(False, help="read a single notebook from stdin.").tag(config=True)
 
     @catch_config_error
     def initialize(self, argv=None):
@@ -236,11 +284,9 @@ class NbConvertApp(JupyterApp):
         self.init_writer()
         self.init_postprocessor()
 
-
     def init_syspath(self):
         """Add the cwd to the sys.path ($PYTHONPATH)"""
         sys.path.insert(0, os.getcwd())
-        
 
     def init_notebooks(self):
         """Construct the list of notebooks.
@@ -266,7 +312,7 @@ class NbConvertApp(JupyterApp):
             globbed_files = glob.glob(pattern)
             globbed_files.extend(glob.glob(pattern + '.ipynb'))
             if not globbed_files:
-                self.log.warn("pattern %r matched no files", pattern)
+                self.log.warning("pattern %r matched no files", pattern)
 
             for filename in globbed_files:
                 if not filename in filenames:
@@ -275,15 +321,14 @@ class NbConvertApp(JupyterApp):
 
     def init_writer(self):
         """Initialize the writer (which is stateless)"""
-        self._writer_class_changed(None, self.writer_class, self.writer_class)
+        self._writer_class_changed({ 'new': self.writer_class })
         self.writer = self.writer_factory(parent=self)
         if hasattr(self.writer, 'build_directory') and self.writer.build_directory != '':
             self.use_output_suffix = False
 
     def init_postprocessor(self):
         """Initialize the postprocessor (which is stateless)"""
-        self._postprocessor_class_changed(None, self.postprocessor_class, 
-            self.postprocessor_class)
+        self._postprocessor_class_changed({'new': self.postprocessor_class})
         if self.postprocessor_factory:
             self.postprocessor = self.postprocessor_factory(parent=self)
 
@@ -299,9 +344,9 @@ class NbConvertApp(JupyterApp):
 
         Returns
         -------
+
         dict
-            resources dictionary for a single notebook that MUST include the
-            following keys:
+            resources dictionary for a single notebook that MUST include the following keys:
                 - config_dir: the location of the Jupyter config directory
                 - unique_key: the notebook name
                 - output_files_dir: a directory where output files (not
@@ -323,7 +368,13 @@ class NbConvertApp(JupyterApp):
         resources = {}
         resources['config_dir'] = self.config_dir
         resources['unique_key'] = notebook_name
-        resources['output_files_dir'] = '%s_files' % notebook_name
+
+        output_files_dir = (self.output_files_dir
+                            .format(notebook_name=notebook_name))
+
+        resources['output_files_dir'] = output_files_dir
+
+        resources['ipywidgets_base_url'] = self.ipywidgets_base_url
 
         return resources
 
